async function g() {
  let A = babelHelpers.decorate([dec], function (_initialize, _await$B) {
    "use strict";

    class A extends _await$B {
      constructor(...args) {
        super(...args);

        _initialize(this);
      }

    }

    return {
      F: A,
      d: []
    };
  }, await B);
}
